async fn handle_message(reflector: &str, msg: &MonitorMessage, pool: &PgPool)Expand description
Dispatches a parsed monitor message to the appropriate handler.
async fn handle_message(reflector: &str, msg: &MonitorMessage, pool: &PgPool)Dispatches a parsed monitor message to the appropriate handler.